@@ -29,21 +29,22 @@ using namespace KAuth;
 K_PLUGIN_FACTORY(WorkspaceOptionsModuleFactory, registerPlugin<WorkspaceOptionsModule>();)
 K_EXPORT_PLUGIN(WorkspaceOptionsModuleFactory("kcmworkspaceoptions"))
 
+static const QString s_osdKey = QStringLiteral("OSD");
 
 WorkspaceOptionsModule::WorkspaceOptionsModule(QWidget *parent, const QVariantList &args)
   : KCModule(parent, args),
-    m_kwinConfig( KSharedConfig::openConfig("kwinrc")),
-    m_ownConfig( KSharedConfig::openConfig("workspaceoptionsrc")),
-    m_plasmaShellAutostart("plasmashell"),
-    m_krunnerAutostart("krunner"),
+    m_kwinConfig( KSharedConfig::openConfig(QStringLiteral("kwinrc"))),
+    m_ownConfig( KSharedConfig::openConfig(QStringLiteral("workspaceoptionsrc"))),
+    m_plasmaShellAutostart(QStringLiteral("plasmashell")),
+    m_krunnerAutostart(QStringLiteral("krunner")),
     m_ui(new Ui::MainPage)
 {
     KAboutData *about =
     new KAboutData(QStringLiteral("kcmworkspaceoptions"), i18n("Global options for the Plasma Workspace"),
-                   QString("1.0"), QString(), KAboutLicense::GPL,
+                   QStringLiteral("1.0"), QString(), KAboutLicense::GPL,
                    i18n("(c) 2009 Marco Martin"));
 
-    about->addAuthor(i18n("Marco Martin"), i18n("Maintainer"), "notmart@gmail.com");
+    about->addAuthor(i18n("Marco Martin"), i18n("Maintainer"), QStringLiteral("notmart@gmail.com"));
 
     setAboutData(about);
 
@@ -52,6 +53,7 @@ WorkspaceOptionsModule::WorkspaceOptionsModule(QWidget *parent, const QVariantLi
     m_ui->setupUi(this);
 
     connect(m_ui->showToolTips, SIGNAL(toggled(bool)), this, SLOT(changed()));
+    connect(m_ui->showOsd, &QCheckBox::toggled, this, static_cast<void(WorkspaceOptionsModule::*)()>(&WorkspaceOptionsModule::changed));
 }
 
 WorkspaceOptionsModule::~WorkspaceOptionsModule()
@@ -62,26 +64,39 @@ WorkspaceOptionsModule::~WorkspaceOptionsModule()
 
 void WorkspaceOptionsModule::save()
 {
+    KSharedConfig::Ptr config = KSharedConfig::openConfig(QStringLiteral("plasmarc"));
+
     {
-        KConfig config("plasmarc");
-        KConfigGroup cg(&config, "PlasmaToolTips");
+        KConfigGroup cg(config, "PlasmaToolTips");
         cg.writeEntry("Delay", m_ui->showToolTips->isChecked() ? 0.7 : -1);
     }
 
+    {
+        KConfigGroup cg(config, QStringLiteral("OSD"));
+        cg.writeEntry("Enabled", m_ui->showOsd->isChecked());
+    }
+
 }
 
 void WorkspaceOptionsModule::load()
 {
+    KSharedConfig::Ptr config = KSharedConfig::openConfig(QStringLiteral("plasmarc"));
+
     {
-        KConfig config("plasmarc");
-        KConfigGroup cg(&config, "PlasmaToolTips");
+        const KConfigGroup cg(config, "PlasmaToolTips");
         m_ui->showToolTips->setChecked(cg.readEntry("Delay", 0.7) > 0);
     }
+
+    {
+        const KConfigGroup cg(config, s_osdKey);
+        m_ui->showOsd->setChecked(cg.readEntry(QStringLiteral("Enabled"), true));
+    }
 }
 
 void WorkspaceOptionsModule::defaults()
 {
     m_ui->showToolTips->setChecked(true);
+    m_ui->showOsd->setChecked(true);
 }
 
 #include "workspaceoptions.moc"
